By chronological order:

        Bram, launched the project
        Kload
        opi
        taziden
        beudbeud
        CapsLock
        Julien Malik
        Titoko
        0x010C
        Eugene Andrienko
        George Angelopoulos
        Quentin Schulz
        toki
